Aquatroll - Blueye SDK

Skip to content

# Aquatroll

## `` aquatroll

Classes:

- `AquaTrollDevice` –

  Aqua Troll Device IDs.

- `AquaTrollDeviceStatus` –

  Aqua Troll Device Status IDs

- `AquaTrollParameter` –

  Aqua Troll Parameter IDs.

- `AquaTrollParameterBlock` –

  In-Situ Parameter Block.

- `AquaTrollProbeMetadata` –

  Attributes:

- `AquaTrollQuality` –

  Aqua Troll Quality IDs.

- `AquaTrollSensor` –

  Aqua Troll Sensor IDs.

- `AquaTrollSensorMetadata` –

  In-Situ AquaTroll 500 sensor metadata.

- `AquaTrollSensorMetadataArray` –

  Attributes:

- `AquaTrollSensorParameters` –

  Attributes:

- `AquaTrollSensorParametersArray` –

  Attributes:

- `AquaTrollSensorStatus` –

  Aqua Troll Sensor Status IDs

- `AquaTrollUnit` –

  Aqua Troll Unit IDs.

- `SetAquaTrollConnectionStatus` –

  Request to change the In-Situ Aqua Troll connection status.

- `SetAquaTrollParameterUnit` –

  Request to set an In-Situ Aqua Troll parameter unit.

- `Type` –

  Type IDs

### `` AquaTrollDevice

Aqua Troll Device IDs.

#### `` AQUA_TROLL_DEVICE_AQUA_TROLL_100 `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_AQUA_TROLL_100 = 10

#### `` AQUA_TROLL_DEVICE_AQUA_TROLL_200 `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_AQUA_TROLL_200 = 5

#### `` AQUA_TROLL_DEVICE_AQUA_TROLL_400 `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_AQUA_TROLL_400 = 18

#### `` AQUA_TROLL_DEVICE_AQUA_TROLL_500 `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_AQUA_TROLL_500 = 33

#### `` AQUA_TROLL_DEVICE_AQUA_TROLL_500_VENTED `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_AQUA_TROLL_500_VENTED = 34

#### `` AQUA_TROLL_DEVICE_AQUA_TROLL_600 `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_AQUA_TROLL_600 = 7

#### `` AQUA_TROLL_DEVICE_AQUA_TROLL_600_VENTED `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_AQUA_TROLL_600_VENTED = 26

#### `` AQUA_TROLL_DEVICE_BAROTROLL_500 `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_BAROTROLL_500 = 3

#### `` AQUA_TROLL_DEVICE_FLOW_TROLL_500 `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_FLOW_TROLL_500 = 11

#### `` AQUA_TROLL_DEVICE_LEVEL_TROLL_300 `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_LEVEL_TROLL_300 = 4

#### `` AQUA_TROLL_DEVICE_LEVEL_TROLL_400 `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_LEVEL_TROLL_400 = 30

#### `` AQUA_TROLL_DEVICE_LEVEL_TROLL_500 `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_LEVEL_TROLL_500 = 1

#### `` AQUA_TROLL_DEVICE_LEVEL_TROLL_700 `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_LEVEL_TROLL_700 = 2

#### `` AQUA_TROLL_DEVICE_RDO_PRO `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_RDO_PRO = 12

#### `` AQUA_TROLL_DEVICE_RDO_PRO_X `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_RDO_PRO_X = 31

#### `` AQUA_TROLL_DEVICE_RDO_TITAN `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_RDO_TITAN = 19

#### `` AQUA_TROLL_DEVICE_RUGGED_BAROTROLL `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_RUGGED_BAROTROLL = 17

#### `` AQUA_TROLL_DEVICE_RUGGED_TROLL_200 `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_RUGGED_TROLL_200 = 16

#### `` AQUA_TROLL_DEVICE_SMARTROLL `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_SMARTROLL = 21

#### `` AQUA_TROLL_DEVICE_UNSPECIFIED `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_UNSPECIFIED = 0

### `` AquaTrollDeviceStatus

Aqua Troll Device Status IDs

#### `` AQUA_TROLL_DEVICE_STATUS_DEVICE_HARDWARE_RESET_OCCURRED `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_STATUS_DEVICE_HARDWARE_RESET_OCCURRED = 10

#### `` AQUA_TROLL_DEVICE_STATUS_DEVICE_MALFUNCTION `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_STATUS_DEVICE_MALFUNCTION = 11

#### `` AQUA_TROLL_DEVICE_STATUS_DEVICE_OFF_LINE `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_STATUS_DEVICE_OFF_LINE = 9

#### `` AQUA_TROLL_DEVICE_STATUS_LOW_BATTERY `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_STATUS_LOW_BATTERY = 13

#### `` AQUA_TROLL_DEVICE_STATUS_LOW_MEMORY `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_STATUS_LOW_MEMORY = 14

#### `` AQUA_TROLL_DEVICE_STATUS_NO_EXTERNAL_POWER `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_STATUS_NO_EXTERNAL_POWER = 12

#### `` AQUA_TROLL_DEVICE_STATUS_POWER_MANAGEMENT_DISABLED `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_STATUS_POWER_MANAGEMENT_DISABLED = 8

#### `` AQUA_TROLL_DEVICE_STATUS_SENSOR_CALIBRATION_WARNING `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_STATUS_SENSOR_CALIBRATION_WARNING = 4

#### `` AQUA_TROLL_DEVICE_STATUS_SENSOR_HIGH_ALARM `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_STATUS_SENSOR_HIGH_ALARM = 0

#### `` AQUA_TROLL_DEVICE_STATUS_SENSOR_HIGH_WARNING `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_STATUS_SENSOR_HIGH_WARNING = 1

#### `` AQUA_TROLL_DEVICE_STATUS_SENSOR_LOW_ALARM `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_STATUS_SENSOR_LOW_ALARM = 3

#### `` AQUA_TROLL_DEVICE_STATUS_SENSOR_LOW_WARNING `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_STATUS_SENSOR_LOW_WARNING = 2

#### `` AQUA_TROLL_DEVICE_STATUS_SENSOR_MALFUNCTION `class-attribute` `instance-attribute`

    AQUA_TROLL_DEVICE_STATUS_SENSOR_MALFUNCTION = 5

### `` AquaTrollParameter

Aqua Troll Parameter IDs.

#### `` AQUA_TROLL_PARAMETER_ACTUAL_CONDUCTIVITY `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_ACTUAL_CONDUCTIVITY = 9

#### `` AQUA_TROLL_PARAMETER_AMMONIA_AS_NITROGEN_NH3_N_CONCENTRATION `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_AMMONIA_AS_NITROGEN_NH3_N_CONCENTRATION = (
        41
    )

#### `` AQUA_TROLL_PARAMETER_AMMONIUM `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_AMMONIUM = 23

#### `` AQUA_TROLL_PARAMETER_AMMONIUM_AS_NITROGEN_NH4_PLUS_N_CONCENTRATION `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_AMMONIUM_AS_NITROGEN_NH4_PLUS_N_CONCENTRATION = (
        39
    )

#### `` AQUA_TROLL_PARAMETER_AMMONIUM_NH4_MV `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_AMMONIUM_NH4_MV = 40

#### `` AQUA_TROLL_PARAMETER_BAROMETRIC_PRESSURE `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_BAROMETRIC_PRESSURE = 16

#### `` AQUA_TROLL_PARAMETER_BATTERY_CAPACITY_REMAINING `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_BATTERY_CAPACITY_REMAINING = 33

#### `` AQUA_TROLL_PARAMETER_BATTERY_VOLTAGE `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_BATTERY_VOLTAGE = 26

#### `` AQUA_TROLL_PARAMETER_BLUE_GREEN_ALGAE_PHYCOCYANIN_CONCENTRATION `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_BLUE_GREEN_ALGAE_PHYCOCYANIN_CONCENTRATION = (
        54
    )

#### `` AQUA_TROLL_PARAMETER_BLUE_GREEN_ALGAE_PHYCOCYANIN_FLUORESCENCE_INTENSITY `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_BLUE_GREEN_ALGAE_PHYCOCYANIN_FLUORESCENCE_INTENSITY = (
        55
    )

#### `` AQUA_TROLL_PARAMETER_BLUE_GREEN_ALGAE_PHYCOERYTHRIN_CONCENTRATION `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_BLUE_GREEN_ALGAE_PHYCOERYTHRIN_CONCENTRATION = (
        58
    )

#### `` AQUA_TROLL_PARAMETER_BLUE_GREEN_ALGAE_PHYCOERYTHRIN_FLUORESCENCE_INTENSITY `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_BLUE_GREEN_ALGAE_PHYCOERYTHRIN_FLUORESCENCE_INTENSITY = (
        59
    )

#### `` AQUA_TROLL_PARAMETER_CHLORIDE `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_CHLORIDE = 24

#### `` AQUA_TROLL_PARAMETER_CHLORIDE_CL_MV `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_CHLORIDE_CL_MV = 36

#### `` AQUA_TROLL_PARAMETER_CHLOROPHYLL_A_CONCENTRATION `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_CHLOROPHYLL_A_CONCENTRATION = 50

#### `` AQUA_TROLL_PARAMETER_CHLOROPHYLL_A_FLUORESCENCE_INTENSITY `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_CHLOROPHYLL_A_FLUORESCENCE_INTENSITY = (
        51
    )

#### `` AQUA_TROLL_PARAMETER_COLORED_DISSOLVED_ORGANIC_MATTER_CONCENTRATION `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_COLORED_DISSOLVED_ORGANIC_MATTER_CONCENTRATION = (
        87
    )

#### `` AQUA_TROLL_PARAMETER_CRUDE_OIL_CONCENTRATION `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_CRUDE_OIL_CONCENTRATION = 80

#### `` AQUA_TROLL_PARAMETER_CRUDE_OIL_FLUORESCENCE_INTENSITY `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_CRUDE_OIL_FLUORESCENCE_INTENSITY = 81

#### `` AQUA_TROLL_PARAMETER_DENSITY_OF_WATER `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_DENSITY_OF_WATER = 14

#### `` AQUA_TROLL_PARAMETER_DEPTH `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_DEPTH = 3

#### `` AQUA_TROLL_PARAMETER_DISSOLVED_OXYGEN_CONCENTRATION `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_DISSOLVED_OXYGEN_CONCENTRATION = 20

#### `` AQUA_TROLL_PARAMETER_DISSOLVED_OXYGEN_SATURATION `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_DISSOLVED_OXYGEN_SATURATION = 21

#### `` AQUA_TROLL_PARAMETER_EH `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_EH = 48

#### `` AQUA_TROLL_PARAMETER_ELEVATION `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_ELEVATION = 8

#### `` AQUA_TROLL_PARAMETER_EXTERNAL_VOLTAGE `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_EXTERNAL_VOLTAGE = 32

#### `` AQUA_TROLL_PARAMETER_FLOW `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_FLOW = 28

#### `` AQUA_TROLL_PARAMETER_FLUORESCEIN_WT_CONCENTRATION `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_FLUORESCEIN_WT_CONCENTRATION = 67

#### `` AQUA_TROLL_PARAMETER_FLUORESCEIN_WT_FLUORESCENCE_INTENSITY `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_FLUORESCEIN_WT_FLUORESCENCE_INTENSITY = (
        68
    )

#### `` AQUA_TROLL_PARAMETER_FLUORESCENT_DISSOLVED_ORGANIC_MATTER_CONCENTRATION `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_FLUORESCENT_DISSOLVED_ORGANIC_MATTER_CONCENTRATION = (
        69
    )

#### `` AQUA_TROLL_PARAMETER_FLUORESCENT_DISSOLVED_ORGANIC_MATTER_FLUORESCENCE_INTENSITY `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_FLUORESCENT_DISSOLVED_ORGANIC_MATTER_FLUORESCENCE_INTENSITY = (
        70
    )

#### `` AQUA_TROLL_PARAMETER_HEAD `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_HEAD = 27

#### `` AQUA_TROLL_PARAMETER_LATITUDE `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_LATITUDE = 6

#### `` AQUA_TROLL_PARAMETER_LEVEL_DEPTH_TO_WATER `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_LEVEL_DEPTH_TO_WATER = 4

#### `` AQUA_TROLL_PARAMETER_LEVEL_SURFACE_ELEVATION `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_LEVEL_SURFACE_ELEVATION = 5

#### `` AQUA_TROLL_PARAMETER_LONGITUDE `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_LONGITUDE = 7

#### `` AQUA_TROLL_PARAMETER_NITRATE `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_NITRATE = 22

#### `` AQUA_TROLL_PARAMETER_NITRATE_AS_NITROGEN_NO3_N_CONCENTRATION `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_NITRATE_AS_NITROGEN_NO3_N_CONCENTRATION = (
        37
    )

#### `` AQUA_TROLL_PARAMETER_NITRATE_NO3_MV `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_NITRATE_NO3_MV = 38

#### `` AQUA_TROLL_PARAMETER_ORP `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_ORP = 19

#### `` AQUA_TROLL_PARAMETER_OXYGEN_PARTIAL_PRESSURE `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_OXYGEN_PARTIAL_PRESSURE = 30

#### `` AQUA_TROLL_PARAMETER_PH `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_PH = 17

#### `` AQUA_TROLL_PARAMETER_PH_MV `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_PH_MV = 18

#### `` AQUA_TROLL_PARAMETER_PRESSURE `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_PRESSURE = 2

#### `` AQUA_TROLL_PARAMETER_RESISTIVITY `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_RESISTIVITY = 11

#### `` AQUA_TROLL_PARAMETER_RHODAMINE_WT_CONCENTRATION `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_RHODAMINE_WT_CONCENTRATION = 34

#### `` AQUA_TROLL_PARAMETER_RHODAMINE_WT_FLUORESCENCE_INTENSITY `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_RHODAMINE_WT_FLUORESCENCE_INTENSITY = (
        35
    )

#### `` AQUA_TROLL_PARAMETER_SALINITY `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_SALINITY = 12

#### `` AQUA_TROLL_PARAMETER_SPECIFIC_CONDUCTIVITY `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_SPECIFIC_CONDUCTIVITY = 10

#### `` AQUA_TROLL_PARAMETER_SPECIFIC_GRAVITY `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_SPECIFIC_GRAVITY = 15

#### `` AQUA_TROLL_PARAMETER_TEMPERATURE `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_TEMPERATURE = 1

#### `` AQUA_TROLL_PARAMETER_TOTAL_AMMONIA_AS_NITROGEN_NH3_N_CONCENTRATION `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_TOTAL_AMMONIA_AS_NITROGEN_NH3_N_CONCENTRATION = (
        42
    )

#### `` AQUA_TROLL_PARAMETER_TOTAL_DISSOLVED_SOLIDS `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_TOTAL_DISSOLVED_SOLIDS = 13

#### `` AQUA_TROLL_PARAMETER_TOTAL_FLOW `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_TOTAL_FLOW = 29

#### `` AQUA_TROLL_PARAMETER_TOTAL_SUSPENDED_SOLIDS `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_TOTAL_SUSPENDED_SOLIDS = 31

#### `` AQUA_TROLL_PARAMETER_TURBIDITY `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_TURBIDITY = 25

#### `` AQUA_TROLL_PARAMETER_UNSPECIFIED `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_UNSPECIFIED = 0

#### `` AQUA_TROLL_PARAMETER_VELOCITY `class-attribute` `instance-attribute`

    AQUA_TROLL_PARAMETER_VELOCITY = 49

### `` AquaTrollParameterBlock

In-Situ Parameter Block.

Up to NUMBER_OF_SENSOR_PARAMETERS blocks may be part of a sensor.

#### `` available_units `class-attribute` `instance-attribute`

    available_units: MutableSequence["AquaTrollUnit"] = (
        RepeatedField(ENUM, number=6, enum="AquaTrollUnit")
    )

#### `` data_quality_ids `class-attribute` `instance-attribute`

    data_quality_ids: MutableSequence["AquaTrollQuality"] = (
        RepeatedField(ENUM, number=7, enum="AquaTrollQuality")
    )

#### `` measured_value `class-attribute` `instance-attribute`

    measured_value: float = Field(FLOAT, number=1)

#### `` off_line_sentinel_value `class-attribute` `instance-attribute`

    off_line_sentinel_value: float = Field(FLOAT, number=5)

#### `` parameter_id `class-attribute` `instance-attribute`

    parameter_id: "AquaTrollParameter" = Field(
        ENUM, number=2, enum="AquaTrollParameter"
    )

#### `` units_id `class-attribute` `instance-attribute`

    units_id: "AquaTrollUnit" = Field(
        ENUM, number=3, enum="AquaTrollUnit"
    )

### `` AquaTrollProbeMetadata

#### `` altitude_coordinate `class-attribute` `instance-attribute`

    altitude_coordinate: float = Field(DOUBLE, number=17)

#### `` boot_code_version `class-attribute` `instance-attribute`

    boot_code_version: int = Field(UINT32, number=7)

#### `` current_time_utc `class-attribute` `instance-attribute`

    current_time_utc: Timestamp = Field(
        MESSAGE, number=18, message=Timestamp
    )

#### `` device_id `class-attribute` `instance-attribute`

    device_id: "AquaTrollDevice" = Field(
        ENUM, number=3, enum="AquaTrollDevice"
    )

#### `` device_name `class-attribute` `instance-attribute`

    device_name: str = Field(STRING, number=13)

#### `` device_serial_number `class-attribute` `instance-attribute`

    device_serial_number: int = Field(UINT32, number=4)

#### `` device_status_flags `class-attribute` `instance-attribute`

    device_status_flags: MutableSequence[
        "AquaTrollDeviceStatus"
    ] = RepeatedField(
        ENUM, number=23, enum="AquaTrollDeviceStatus"
    )

#### `` firmware_version `class-attribute` `instance-attribute`

    firmware_version: int = Field(UINT32, number=6)

#### `` hardware_version `class-attribute` `instance-attribute`

    hardware_version: int = Field(UINT32, number=8)

#### `` last_battery_change `class-attribute` `instance-attribute`

    last_battery_change: Timestamp = Field(
        MESSAGE, number=12, message=Timestamp
    )

#### `` latitude_coordinate `class-attribute` `instance-attribute`

    latitude_coordinate: float = Field(DOUBLE, number=15)

#### `` longitude_coordinate `class-attribute` `instance-attribute`

    longitude_coordinate: float = Field(DOUBLE, number=16)

#### `` manufacture_date `class-attribute` `instance-attribute`

    manufacture_date: Timestamp = Field(
        MESSAGE, number=5, message=Timestamp
    )

#### `` max_data_logs `class-attribute` `instance-attribute`

    max_data_logs: int = Field(UINT32, number=9)

#### `` register_map_template_version `class-attribute` `instance-attribute`

    register_map_template_version: int = Field(UINT32, number=2)

#### `` sensors `class-attribute` `instance-attribute`

    sensors: MutableSequence["AquaTrollSensor"] = RepeatedField(
        ENUM, number=22, enum="AquaTrollSensor"
    )

#### `` site_name `class-attribute` `instance-attribute`

    site_name: str = Field(STRING, number=14)

#### `` status `class-attribute` `instance-attribute`

    status: bool = Field(BOOL, number=24)

#### `` timestamp `class-attribute` `instance-attribute`

    timestamp: Timestamp = Field(
        MESSAGE, number=1, message=Timestamp
    )

#### `` total_battery_ticks `class-attribute` `instance-attribute`

    total_battery_ticks: int = Field(UINT32, number=11)

#### `` total_data_log_memory `class-attribute` `instance-attribute`

    total_data_log_memory: int = Field(UINT32, number=10)

#### `` used_battery_ticks `class-attribute` `instance-attribute`

    used_battery_ticks: int = Field(UINT32, number=20)

#### `` used_data_log_memory `class-attribute` `instance-attribute`

    used_data_log_memory: int = Field(UINT32, number=21)

### `` AquaTrollQuality

Aqua Troll Quality IDs.

#### `` AQUA_TROLL_QUALITY_CALIBRATING `class-attribute` `instance-attribute`

    AQUA_TROLL_QUALITY_CALIBRATING = 6

#### `` AQUA_TROLL_QUALITY_ERROR `class-attribute` `instance-attribute`

    AQUA_TROLL_QUALITY_ERROR = 3

#### `` AQUA_TROLL_QUALITY_FACTORY_CAL_EXPIRED `class-attribute` `instance-attribute`

    AQUA_TROLL_QUALITY_FACTORY_CAL_EXPIRED = 2

#### `` AQUA_TROLL_QUALITY_NORMAL `class-attribute` `instance-attribute`

    AQUA_TROLL_QUALITY_NORMAL = 0

#### `` AQUA_TROLL_QUALITY_OFF_LINE `class-attribute` `instance-attribute`

    AQUA_TROLL_QUALITY_OFF_LINE = 7

#### `` AQUA_TROLL_QUALITY_SENSOR_WARNING `class-attribute` `instance-attribute`

    AQUA_TROLL_QUALITY_SENSOR_WARNING = 5

#### `` AQUA_TROLL_QUALITY_USER_CAL_EXPIRED `class-attribute` `instance-attribute`

    AQUA_TROLL_QUALITY_USER_CAL_EXPIRED = 1

#### `` AQUA_TROLL_QUALITY_WARM_UP `class-attribute` `instance-attribute`

    AQUA_TROLL_QUALITY_WARM_UP = 4

### `` AquaTrollSensor

Aqua Troll Sensor IDs.

#### `` AQUA_TROLL_SENSOR_AMMONIUM_ANALOG_SENSOR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_AMMONIUM_ANALOG_SENSOR = 30

#### `` AQUA_TROLL_SENSOR_AMMONIUM_ISE_SENSOR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_AMMONIUM_ISE_SENSOR = 71

#### `` AQUA_TROLL_SENSOR_BLUE_GREEN_ALGAE_PHYCOCYANIN_SENSOR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_BLUE_GREEN_ALGAE_PHYCOCYANIN_SENSOR = 64

#### `` AQUA_TROLL_SENSOR_BLUE_GREEN_ALGAE_PHYCOERYTHRIN_SENSOR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_BLUE_GREEN_ALGAE_PHYCOERYTHRIN_SENSOR = 65

#### `` AQUA_TROLL_SENSOR_CHLORIDE_ANALOG_SENSOR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_CHLORIDE_ANALOG_SENSOR = 31

#### `` AQUA_TROLL_SENSOR_CHLORIDE_ISE_SENSOR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_CHLORIDE_ISE_SENSOR = 72

#### `` AQUA_TROLL_SENSOR_CHLOROPHYLL_A_SENSOR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_CHLOROPHYLL_A_SENSOR = 62

#### `` AQUA_TROLL_SENSOR_CONDUCTIVITY_AND_TEMPERATURE `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_CONDUCTIVITY_AND_TEMPERATURE = 35

#### `` AQUA_TROLL_SENSOR_CONDUCTIVITY_SENSOR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_CONDUCTIVITY_SENSOR = 56

#### `` AQUA_TROLL_SENSOR_CRUDE_OIL_SENSOR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_CRUDE_OIL_SENSOR = 67

#### `` AQUA_TROLL_SENSOR_DISSOLVED_OXYGEN_CLARK_CELL_ANALOG_SENSOR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_DISSOLVED_OXYGEN_CLARK_CELL_ANALOG_SENSOR = (
        28
    )

#### `` AQUA_TROLL_SENSOR_NITRATE_ANALOG_SENSOR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_NITRATE_ANALOG_SENSOR = 29

#### `` AQUA_TROLL_SENSOR_NITRATE_ISE_SENSOR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_NITRATE_ISE_SENSOR = 70

#### `` AQUA_TROLL_SENSOR_NOT_USED `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_NOT_USED = 20

#### `` AQUA_TROLL_SENSOR_OPTICAL_DISSOLVED_OXYGEN_WITH_TEMPERATURE `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_OPTICAL_DISSOLVED_OXYGEN_WITH_TEMPERATURE = (
        42
    )

#### `` AQUA_TROLL_SENSOR_PH_ANALOG_SENSOR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_PH_ANALOG_SENSOR = 26

#### `` AQUA_TROLL_SENSOR_PH_ORP_ANALOG_SENSOR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_PH_ORP_ANALOG_SENSOR = 27

#### `` AQUA_TROLL_SENSOR_PH_ORP_SENSOR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_PH_ORP_SENSOR = 58

#### `` AQUA_TROLL_SENSOR_PROBE_PARAMETERS `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_PROBE_PARAMETERS = 79

#### `` AQUA_TROLL_SENSOR_RDO_SENSOR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_RDO_SENSOR = 57

#### `` AQUA_TROLL_SENSOR_RHODAMINE_WT_SENSOR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_RHODAMINE_WT_SENSOR = 60

#### `` AQUA_TROLL_SENSOR_S1000_PSI_FULL_SCALE_ABSOLUTE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S1000_PSI_FULL_SCALE_ABSOLUTE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE = (
        8
    )

#### `` AQUA_TROLL_SENSOR_S100_FOOT_FULL_SCALE_LEVEL_WITH_ABSOLUTE_PRESSURE_AND_TEMPERATURE `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S100_FOOT_FULL_SCALE_LEVEL_WITH_ABSOLUTE_PRESSURE_AND_TEMPERATURE = (
        32
    )

#### `` AQUA_TROLL_SENSOR_S100_PSI_FULL_SCALE_ABSOLUTE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S100_PSI_FULL_SCALE_ABSOLUTE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE = (
        10
    )

#### `` AQUA_TROLL_SENSOR_S100_PSI_FULL_SCALE_ABSOLUTE_PRESSURE_WITH_LEVEL_TEMPERATURE_AND_CONDUCTIVITY `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S100_PSI_FULL_SCALE_ABSOLUTE_PRESSURE_WITH_LEVEL_TEMPERATURE_AND_CONDUCTIVITY = (
        22
    )

#### `` AQUA_TROLL_SENSOR_S100_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S100_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE = (
        5
    )

#### `` AQUA_TROLL_SENSOR_S100_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_TEMPERATURE_AND_CONDUCTIVITY `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S100_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_TEMPERATURE_AND_CONDUCTIVITY = (
        17
    )

#### `` AQUA_TROLL_SENSOR_S100_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_TEMPERATURE_HEAD_AND_FLOW `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S100_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_TEMPERATURE_HEAD_AND_FLOW = (
        39
    )

#### `` AQUA_TROLL_SENSOR_S15_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S15_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE = (
        3
    )

#### `` AQUA_TROLL_SENSOR_S15_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_TEMPERATURE_AND_CONDUCTIVITY `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S15_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_TEMPERATURE_AND_CONDUCTIVITY = (
        15
    )

#### `` AQUA_TROLL_SENSOR_S15_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_TEMPERATURE_HEAD_AND_FLOW `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S15_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_TEMPERATURE_HEAD_AND_FLOW = (
        37
    )

#### `` AQUA_TROLL_SENSOR_S165_PSI_FULL_SCALE_ABSOLUTE_PRESSURE `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S165_PSI_FULL_SCALE_ABSOLUTE_PRESSURE = 25

#### `` AQUA_TROLL_SENSOR_S1_BAR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S1_BAR = 43

#### `` AQUA_TROLL_SENSOR_S250_FOOT_FULL_SCALE_LEVEL_WITH_ABSOLUTE_PRESSURE_AND_TEMPERATURE `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S250_FOOT_FULL_SCALE_LEVEL_WITH_ABSOLUTE_PRESSURE_AND_TEMPERATURE = (
        33
    )

#### `` AQUA_TROLL_SENSOR_S2_BAR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S2_BAR = 44

#### `` AQUA_TROLL_SENSOR_S300_PSI_FULL_SCALE_ABSOLUTE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S300_PSI_FULL_SCALE_ABSOLUTE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE = (
        11
    )

#### `` AQUA_TROLL_SENSOR_S300_PSI_FULL_SCALE_ABSOLUTE_PRESSURE_WITH_LEVEL_TEMPERATURE_AND_CONDUCTIVITY `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S300_PSI_FULL_SCALE_ABSOLUTE_PRESSURE_WITH_LEVEL_TEMPERATURE_AND_CONDUCTIVITY = (
        23
    )

#### `` AQUA_TROLL_SENSOR_S300_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S300_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE = (
        6
    )

#### `` AQUA_TROLL_SENSOR_S300_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_TEMPERATURE_AND_CONDUCTIVITY `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S300_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_TEMPERATURE_AND_CONDUCTIVITY = (
        18
    )

#### `` AQUA_TROLL_SENSOR_S300_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_TEMPERATURE_HEAD_AND_FLOW `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S300_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_TEMPERATURE_HEAD_AND_FLOW = (
        40
    )

#### `` AQUA_TROLL_SENSOR_S30_FOOT_FULL_SCALE_LEVEL_WITH_ABSOLUTE_PRESSURE_AND_TEMPERATURE `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S30_FOOT_FULL_SCALE_LEVEL_WITH_ABSOLUTE_PRESSURE_AND_TEMPERATURE = (
        34
    )

#### `` AQUA_TROLL_SENSOR_S30_PSI_FULL_SCALE_ABSOLUTE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S30_PSI_FULL_SCALE_ABSOLUTE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE = (
        9
    )

#### `` AQUA_TROLL_SENSOR_S30_PSI_FULL_SCALE_ABSOLUTE_PRESSURE_WITH_LEVEL_TEMPERATURE_AND_CONDUCTIVITY `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S30_PSI_FULL_SCALE_ABSOLUTE_PRESSURE_WITH_LEVEL_TEMPERATURE_AND_CONDUCTIVITY = (
        21
    )

#### `` AQUA_TROLL_SENSOR_S30_PSI_FULL_SCALE_ABSOLUTE_PRESSURE_WITH_TEMPERATURE `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S30_PSI_FULL_SCALE_ABSOLUTE_PRESSURE_WITH_TEMPERATURE = (
        13
    )

#### `` AQUA_TROLL_SENSOR_S30_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S30_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE = (
        4
    )

#### `` AQUA_TROLL_SENSOR_S30_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_TEMPERATURE_AND_CONDUCTIVITY `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S30_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_TEMPERATURE_AND_CONDUCTIVITY = (
        16
    )

#### `` AQUA_TROLL_SENSOR_S30_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_TEMPERATURE_HEAD_AND_FLOW `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S30_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_TEMPERATURE_HEAD_AND_FLOW = (
        38
    )

#### `` AQUA_TROLL_SENSOR_S500_PSI_FULL_SCALE_ABSOLUTE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S500_PSI_FULL_SCALE_ABSOLUTE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE = (
        12
    )

#### `` AQUA_TROLL_SENSOR_S500_PSI_FULL_SCALE_ABSOLUTE_PRESSURE_WITH_LEVEL_TEMPERATURE_AND_CONDUCTIVITY `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S500_PSI_FULL_SCALE_ABSOLUTE_PRESSURE_WITH_LEVEL_TEMPERATURE_AND_CONDUCTIVITY = (
        24
    )

#### `` AQUA_TROLL_SENSOR_S500_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S500_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE = (
        7
    )

#### `` AQUA_TROLL_SENSOR_S500_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_TEMPERATURE_AND_CONDUCTIVITY `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S500_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_TEMPERATURE_AND_CONDUCTIVITY = (
        19
    )

#### `` AQUA_TROLL_SENSOR_S500_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_TEMPERATURE_HEAD_AND_FLOW `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S500_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_TEMPERATURE_HEAD_AND_FLOW = (
        41
    )

#### `` AQUA_TROLL_SENSOR_S5_BAR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S5_BAR = 45

#### `` AQUA_TROLL_SENSOR_S5_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S5_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_AND_TEMPERATURE = (
        2
    )

#### `` AQUA_TROLL_SENSOR_S5_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_TEMPERATURE_AND_CONDUCTIVITY `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S5_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_LEVEL_TEMPERATURE_AND_CONDUCTIVITY = (
        14
    )

#### `` AQUA_TROLL_SENSOR_S5_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_TEMPERATURE_HEAD_AND_FLOW `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_S5_PSI_FULL_SCALE_GAUGE_PRESSURE_WITH_TEMPERATURE_HEAD_AND_FLOW = (
        36
    )

#### `` AQUA_TROLL_SENSOR_TEMPERATURE `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_TEMPERATURE = 1

#### `` AQUA_TROLL_SENSOR_TEMPERATURE_SENSOR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_TEMPERATURE_SENSOR = 55

#### `` AQUA_TROLL_SENSOR_TURBIDITY_SENSOR `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_TURBIDITY_SENSOR = 50

#### `` AQUA_TROLL_SENSOR_UNSPECIFIED `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_UNSPECIFIED = 0

### `` AquaTrollSensorMetadata

In-Situ AquaTroll 500 sensor metadata.

(Mostly) static information about a connected sensor.

Refer to Section 7 Sensor Common Registers in the In-Situ Modbus Communication Protocol.

#### `` alarm_and_warning_enable_bits `class-attribute` `instance-attribute`

    alarm_and_warning_enable_bits: int = Field(
        UINT32, number=13
    )

#### `` alarm_and_warning_parameter_number `class-attribute` `instance-attribute`

    alarm_and_warning_parameter_number: int = Field(
        UINT32, number=12
    )

#### `` fast_sample_rate_in_milliseconds `class-attribute` `instance-attribute`

    fast_sample_rate_in_milliseconds: int = Field(
        UINT32, number=10
    )

#### `` high_alarm_clear_value `class-attribute` `instance-attribute`

    high_alarm_clear_value: float = Field(FLOAT, number=15)

#### `` high_alarm_set_value `class-attribute` `instance-attribute`

    high_alarm_set_value: float = Field(FLOAT, number=14)

#### `` high_warning_clear_value `class-attribute` `instance-attribute`

    high_warning_clear_value: float = Field(FLOAT, number=17)

#### `` high_warning_set_value `class-attribute` `instance-attribute`

    high_warning_set_value: float = Field(FLOAT, number=16)

#### `` last_factory_calibration `class-attribute` `instance-attribute`

    last_factory_calibration: Timestamp = Field(
        MESSAGE, number=5, message=Timestamp
    )

#### `` last_user_calibration `class-attribute` `instance-attribute`

    last_user_calibration: Timestamp = Field(
        MESSAGE, number=7, message=Timestamp
    )

#### `` low_alarm_clear_value `class-attribute` `instance-attribute`

    low_alarm_clear_value: float = Field(FLOAT, number=20)

#### `` low_alarm_set_value `class-attribute` `instance-attribute`

    low_alarm_set_value: float = Field(FLOAT, number=21)

#### `` low_warning_clear_value `class-attribute` `instance-attribute`

    low_warning_clear_value: float = Field(FLOAT, number=18)

#### `` low_warning_set_value `class-attribute` `instance-attribute`

    low_warning_set_value: float = Field(FLOAT, number=19)

#### `` next_factory_calibration `class-attribute` `instance-attribute`

    next_factory_calibration: Timestamp = Field(
        MESSAGE, number=6, message=Timestamp
    )

#### `` next_user_calibration `class-attribute` `instance-attribute`

    next_user_calibration: Timestamp = Field(
        MESSAGE, number=8, message=Timestamp
    )

#### `` number_of_sensor_parameters `class-attribute` `instance-attribute`

    number_of_sensor_parameters: int = Field(UINT32, number=11)

#### `` parameter_blocks `class-attribute` `instance-attribute`

    parameter_blocks: MutableSequence[
        "AquaTrollParameterBlock"
    ] = RepeatedField(
        MESSAGE, number=22, message="AquaTrollParameterBlock"
    )

#### `` sensor_id `class-attribute` `instance-attribute`

    sensor_id: "AquaTrollSensor" = Field(
        ENUM, number=2, enum="AquaTrollSensor"
    )

#### `` sensor_serial_number `class-attribute` `instance-attribute`

    sensor_serial_number: int = Field(UINT32, number=3)

#### `` sensor_status_flags `class-attribute` `instance-attribute`

    sensor_status_flags: MutableSequence[
        "AquaTrollSensorStatus"
    ] = RepeatedField(
        ENUM, number=23, enum="AquaTrollSensorStatus"
    )

#### `` timestamp `class-attribute` `instance-attribute`

    timestamp: Timestamp = Field(
        MESSAGE, number=1, message=Timestamp
    )

#### `` warm_up_time_in_milliseconds `class-attribute` `instance-attribute`

    warm_up_time_in_milliseconds: int = Field(UINT32, number=9)

### `` AquaTrollSensorMetadataArray

#### `` sensors `class-attribute` `instance-attribute`

    sensors: MutableSequence["AquaTrollSensorMetadata"] = (
        RepeatedField(
            MESSAGE, number=2, message="AquaTrollSensorMetadata"
        )
    )

#### `` timestamp `class-attribute` `instance-attribute`

    timestamp: Timestamp = Field(
        MESSAGE, number=1, message=Timestamp
    )

### `` AquaTrollSensorParameters

#### `` parameter_blocks `class-attribute` `instance-attribute`

    parameter_blocks: MutableSequence[
        "AquaTrollParameterBlock"
    ] = RepeatedField(
        MESSAGE, number=3, message="AquaTrollParameterBlock"
    )

#### `` sensor_id `class-attribute` `instance-attribute`

    sensor_id: "AquaTrollSensor" = Field(
        ENUM, number=2, enum="AquaTrollSensor"
    )

### `` AquaTrollSensorParametersArray

#### `` sensors `class-attribute` `instance-attribute`

    sensors: MutableSequence["AquaTrollSensorParameters"] = (
        RepeatedField(
            MESSAGE,
            number=2,
            message="AquaTrollSensorParameters",
        )
    )

#### `` timestamp `class-attribute` `instance-attribute`

    timestamp: Timestamp = Field(
        MESSAGE, number=1, message=Timestamp
    )

### `` AquaTrollSensorStatus

Aqua Troll Sensor Status IDs

#### `` AQUA_TROLL_SENSOR_STATUS_SENSOR_CALIBRATION_WARNING `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_STATUS_SENSOR_CALIBRATION_WARNING = 4

#### `` AQUA_TROLL_SENSOR_STATUS_SENSOR_HIGH_ALARM `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_STATUS_SENSOR_HIGH_ALARM = 0

#### `` AQUA_TROLL_SENSOR_STATUS_SENSOR_HIGH_WARNING `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_STATUS_SENSOR_HIGH_WARNING = 1

#### `` AQUA_TROLL_SENSOR_STATUS_SENSOR_LOW_ALARM `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_STATUS_SENSOR_LOW_ALARM = 3

#### `` AQUA_TROLL_SENSOR_STATUS_SENSOR_LOW_WARNING `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_STATUS_SENSOR_LOW_WARNING = 2

#### `` AQUA_TROLL_SENSOR_STATUS_SENSOR_MALFUNCTION `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_STATUS_SENSOR_MALFUNCTION = 5

#### `` AQUA_TROLL_SENSOR_STATUS_SENSOR_MODE_BIT_1 `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_STATUS_SENSOR_MODE_BIT_1 = 8

#### `` AQUA_TROLL_SENSOR_STATUS_SENSOR_MODE_BIT_2 `class-attribute` `instance-attribute`

    AQUA_TROLL_SENSOR_STATUS_SENSOR_MODE_BIT_2 = 9

### `` AquaTrollUnit

Aqua Troll Unit IDs.

#### `` AQUA_TROLL_UNIT_ACRE_FEET `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_ACRE_FEET = 230

#### `` AQUA_TROLL_UNIT_ACRE_INCHES `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_ACRE_INCHES = 234

#### `` AQUA_TROLL_UNIT_AMPS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_AMPS = 291

#### `` AQUA_TROLL_UNIT_BARS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_BARS = 20

#### `` AQUA_TROLL_UNIT_CENTIMETERS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_CENTIMETERS = 34

#### `` AQUA_TROLL_UNIT_CENTIMETERS_OF_WATER `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_CENTIMETERS_OF_WATER = 24

#### `` AQUA_TROLL_UNIT_CUBIC_FEET `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_CUBIC_FEET = 225

#### `` AQUA_TROLL_UNIT_CUBIC_FEET_PER_DAY `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_CUBIC_FEET_PER_DAY = 212

#### `` AQUA_TROLL_UNIT_CUBIC_FEET_PER_HOUR `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_CUBIC_FEET_PER_HOUR = 211

#### `` AQUA_TROLL_UNIT_CUBIC_FEET_PER_MINUTE `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_CUBIC_FEET_PER_MINUTE = 210

#### `` AQUA_TROLL_UNIT_CUBIC_FEET_PER_SECOND `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_CUBIC_FEET_PER_SECOND = 209

#### `` AQUA_TROLL_UNIT_CUBIC_METERS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_CUBIC_METERS = 228

#### `` AQUA_TROLL_UNIT_CUBIC_METERS_PER_DAY `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_CUBIC_METERS_PER_DAY = 220

#### `` AQUA_TROLL_UNIT_CUBIC_METERS_PER_HOUR `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_CUBIC_METERS_PER_HOUR = 219

#### `` AQUA_TROLL_UNIT_CUBIC_METERS_PER_MINUTE `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_CUBIC_METERS_PER_MINUTE = 218

#### `` AQUA_TROLL_UNIT_CUBIC_METERS_PER_SECOND `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_CUBIC_METERS_PER_SECOND = 217

#### `` AQUA_TROLL_UNIT_DEGREES `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_DEGREES = 49

#### `` AQUA_TROLL_UNIT_FEET `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_FEET = 38

#### `` AQUA_TROLL_UNIT_FEET_PER_SECOND `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_FEET_PER_SECOND = 305

#### `` AQUA_TROLL_UNIT_FORMAZIN_NEPHELOMETRIC_UNITS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_FORMAZIN_NEPHELOMETRIC_UNITS = 193

#### `` AQUA_TROLL_UNIT_FORMAZIN_TURBIDITY_UNITS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_FORMAZIN_TURBIDITY_UNITS = 195

#### `` AQUA_TROLL_UNIT_GALLONS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_GALLONS = 226

#### `` AQUA_TROLL_UNIT_GALLONS_PER_HOUR `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_GALLONS_PER_HOUR = 215

#### `` AQUA_TROLL_UNIT_GALLONS_PER_MINUTE `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_GALLONS_PER_MINUTE = 214

#### `` AQUA_TROLL_UNIT_GALLONS_PER_SECOND `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_GALLONS_PER_SECOND = 213

#### `` AQUA_TROLL_UNIT_GRAMS_PER_CUBIC_CENTIMETER `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_GRAMS_PER_CUBIC_CENTIMETER = 129

#### `` AQUA_TROLL_UNIT_GRAMS_PER_LITER `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_GRAMS_PER_LITER = 120

#### `` AQUA_TROLL_UNIT_INCHES `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_INCHES = 37

#### `` AQUA_TROLL_UNIT_INCHES_OF_MERCURY `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_INCHES_OF_MERCURY = 23

#### `` AQUA_TROLL_UNIT_INCHES_OF_WATER `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_INCHES_OF_WATER = 25

#### `` AQUA_TROLL_UNIT_KILOMETER `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_KILOMETER = 36

#### `` AQUA_TROLL_UNIT_KILOPASCALS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_KILOPASCALS = 19

#### `` AQUA_TROLL_UNIT_LITERS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_LITERS = 229

#### `` AQUA_TROLL_UNIT_LITERS_PER_HOUR `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_LITERS_PER_HOUR = 276

#### `` AQUA_TROLL_UNIT_LITERS_PER_MINUTE `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_LITERS_PER_MINUTE = 275

#### `` AQUA_TROLL_UNIT_LITERS_PER_SECOND `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_LITERS_PER_SECOND = 221

#### `` AQUA_TROLL_UNIT_METERS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_METERS = 35

#### `` AQUA_TROLL_UNIT_METERS_PER_SECOND `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_METERS_PER_SECOND = 306

#### `` AQUA_TROLL_UNIT_MICROAMPS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_MICROAMPS = 289

#### `` AQUA_TROLL_UNIT_MICROGRAMS_PER_LITER `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_MICROGRAMS_PER_LITER = 118

#### `` AQUA_TROLL_UNIT_MICROMOLES_PER_LITER_DEPRECATED `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_MICROMOLES_PER_LITER_DEPRECATED = 119

#### `` AQUA_TROLL_UNIT_MICROSIEMENS_PER_CENTIMETER `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_MICROSIEMENS_PER_CENTIMETER = 65

#### `` AQUA_TROLL_UNIT_MICRO_VOLTS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_MICRO_VOLTS = 161

#### `` AQUA_TROLL_UNIT_MILLIAMPS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_MILLIAMPS = 290

#### `` AQUA_TROLL_UNIT_MILLIBARS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_MILLIBARS = 21

#### `` AQUA_TROLL_UNIT_MILLIGRAMS_PER_LITER `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_MILLIGRAMS_PER_LITER = 117

#### `` AQUA_TROLL_UNIT_MILLILITERS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_MILLILITERS = 231

#### `` AQUA_TROLL_UNIT_MILLILITERS_PER_HOUR `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_MILLILITERS_PER_HOUR = 274

#### `` AQUA_TROLL_UNIT_MILLILITERS_PER_MINUTE `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_MILLILITERS_PER_MINUTE = 223

#### `` AQUA_TROLL_UNIT_MILLILITERS_PER_SECOND `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_MILLILITERS_PER_SECOND = 273

#### `` AQUA_TROLL_UNIT_MILLIMETERS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_MILLIMETERS = 33

#### `` AQUA_TROLL_UNIT_MILLIMETERS_OF_MERCURY `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_MILLIMETERS_OF_MERCURY = 22

#### `` AQUA_TROLL_UNIT_MILLIONS_OF_GALLONS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_MILLIONS_OF_GALLONS = 227

#### `` AQUA_TROLL_UNIT_MILLIONS_OF_GALLONS_PER_DAY `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_MILLIONS_OF_GALLONS_PER_DAY = 216

#### `` AQUA_TROLL_UNIT_MILLIONS_OF_LITERS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_MILLIONS_OF_LITERS = 232

#### `` AQUA_TROLL_UNIT_MILLIONS_OF_LITERS_PER_DAY `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_MILLIONS_OF_LITERS_PER_DAY = 222

#### `` AQUA_TROLL_UNIT_MILLISIEMENS_PER_CENTIMETER `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_MILLISIEMENS_PER_CENTIMETER = 66

#### `` AQUA_TROLL_UNIT_MILLI_VOLTS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_MILLI_VOLTS = 162

#### `` AQUA_TROLL_UNIT_MINUTES `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_MINUTES = 50

#### `` AQUA_TROLL_UNIT_NEPHELOMETRIC_TURBIDITY_UNITS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_NEPHELOMETRIC_TURBIDITY_UNITS = 194

#### `` AQUA_TROLL_UNIT_OHM_CENTIMETERS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_OHM_CENTIMETERS = 81

#### `` AQUA_TROLL_UNIT_PARTS_PER_BILLION `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_PARTS_PER_BILLION = 121

#### `` AQUA_TROLL_UNIT_PARTS_PER_MILLION `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_PARTS_PER_MILLION = 113

#### `` AQUA_TROLL_UNIT_PARTS_PER_MILLION_CHLORIDE `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_PARTS_PER_MILLION_CHLORIDE = 116

#### `` AQUA_TROLL_UNIT_PARTS_PER_MILLION_NITROGEN `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_PARTS_PER_MILLION_NITROGEN = 115

#### `` AQUA_TROLL_UNIT_PARTS_PER_THOUSAND `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_PARTS_PER_THOUSAND = 114

#### `` AQUA_TROLL_UNIT_PARTS_PER_THOUSAND_SALINITY `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_PARTS_PER_THOUSAND_SALINITY = 98

#### `` AQUA_TROLL_UNIT_PASCALS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_PASCALS = 18

#### `` AQUA_TROLL_UNIT_PERCENT `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_PERCENT = 241

#### `` AQUA_TROLL_UNIT_PERCENT_SATURATION `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_PERCENT_SATURATION = 177

#### `` AQUA_TROLL_UNIT_PH `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_PH = 145

#### `` AQUA_TROLL_UNIT_POUNDS_PER_SQUARE_INCH `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_POUNDS_PER_SQUARE_INCH = 17

#### `` AQUA_TROLL_UNIT_PRACTICAL_SALINITY_UNITS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_PRACTICAL_SALINITY_UNITS = 97

#### `` AQUA_TROLL_UNIT_RELATIVE_FLUORESCENCE_UNITS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_RELATIVE_FLUORESCENCE_UNITS = 257

#### `` AQUA_TROLL_UNIT_SECONDS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_SECONDS = 51

#### `` AQUA_TROLL_UNIT_STANDARD_ATMOSPHERE `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_STANDARD_ATMOSPHERE = 27

#### `` AQUA_TROLL_UNIT_TEMP_CELSIUS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_TEMP_CELSIUS = 1

#### `` AQUA_TROLL_UNIT_TEMP_FARENHEIT `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_TEMP_FARENHEIT = 2

#### `` AQUA_TROLL_UNIT_TEMP_KELVIN `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_TEMP_KELVIN = 3

#### `` AQUA_TROLL_UNIT_THOUSANDS_OF_LITERS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_THOUSANDS_OF_LITERS = 233

#### `` AQUA_TROLL_UNIT_THOUSANDS_OF_LITERS_PER_DAY `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_THOUSANDS_OF_LITERS_PER_DAY = 224

#### `` AQUA_TROLL_UNIT_TORR `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_TORR = 26

#### `` AQUA_TROLL_UNIT_UNSPECIFIED `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_UNSPECIFIED = 0

#### `` AQUA_TROLL_UNIT_VOLTS `class-attribute` `instance-attribute`

    AQUA_TROLL_UNIT_VOLTS = 163

### `` SetAquaTrollConnectionStatus

Request to change the In-Situ Aqua Troll connection status.

#### `` connected `class-attribute` `instance-attribute`

    connected: bool = Field(BOOL, number=1)

### `` SetAquaTrollParameterUnit

Request to set an In-Situ Aqua Troll parameter unit.

#### `` parameter_id `class-attribute` `instance-attribute`

    parameter_id: "AquaTrollParameter" = Field(
        ENUM, number=2, enum="AquaTrollParameter"
    )

#### `` sensor_id `class-attribute` `instance-attribute`

    sensor_id: "AquaTrollSensor" = Field(
        ENUM, number=1, enum="AquaTrollSensor"
    )

#### `` unit_id `class-attribute` `instance-attribute`

    unit_id: "AquaTrollUnit" = Field(
        ENUM, number=3, enum="AquaTrollUnit"
    )

### `` Type

Type IDs

#### `` TYPE_CHARACTER `class-attribute` `instance-attribute`

    TYPE_CHARACTER = 7

#### `` TYPE_DOUBLE `class-attribute` `instance-attribute`

    TYPE_DOUBLE = 6

#### `` TYPE_FLOAT `class-attribute` `instance-attribute`

    TYPE_FLOAT = 5

#### `` TYPE_LONG `class-attribute` `instance-attribute`

    TYPE_LONG = 3

#### `` TYPE_SHORT `class-attribute` `instance-attribute`

    TYPE_SHORT = 1

#### `` TYPE_STRING `class-attribute` `instance-attribute`

    TYPE_STRING = 8

#### `` TYPE_TIME `class-attribute` `instance-attribute`

    TYPE_TIME = 9

#### `` TYPE_UNSIGNED_LONG `class-attribute` `instance-attribute`

    TYPE_UNSIGNED_LONG = 4

#### `` TYPE_UNSIGNED_SHORT `class-attribute` `instance-attribute`

    TYPE_UNSIGNED_SHORT = 2

#### `` TYPE_UNSPECIFIED `class-attribute` `instance-attribute`

    TYPE_UNSPECIFIED = 0